Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(856)

Unified Diff: content/public/common/content_features.cc

Issue 2450833003: Separate rAF aligned Touch and Mouse Input settings (Closed)
Patch Set: Fix nits Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/common/content_features.h ('k') | content/renderer/input/main_thread_event_queue.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/common/content_features.cc
diff --git a/content/public/common/content_features.cc b/content/public/common/content_features.cc
index e8edd90a5a2c1ef64b4604e6eff0a48ba120ace8..719f35ac4597c7381b80cd211dbe67774fa3fa44 100644
--- a/content/public/common/content_features.cc
+++ b/content/public/common/content_features.cc
@@ -146,9 +146,13 @@ const base::Feature kPointerEvents{"PointerEvent",
const base::Feature kPointerEventV1SpecCapturing{
"PointerEventV1SpecCapturing", base::FEATURE_DISABLED_BY_DEFAULT};
-// RAF aligned input events support.
-const base::Feature kRafAlignedInputEvents{"RafAlignedInput",
- base::FEATURE_DISABLED_BY_DEFAULT};
+// RAF aligned mouse input events support.
+const base::Feature kRafAlignedMouseInputEvents{
+ "RafAlignedMouseInput", base::FEATURE_DISABLED_BY_DEFAULT};
+
+// RAF aligned touch input events support.
+const base::Feature kRafAlignedTouchInputEvents{
+ "RafAlignedTouchInput", base::FEATURE_DISABLED_BY_DEFAULT};
// If Pepper 3D Image Chromium is allowed, this feature controls whether it is
// enabled.
« no previous file with comments | « content/public/common/content_features.h ('k') | content/renderer/input/main_thread_event_queue.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698